@@ -2,14 +2,13 @@ use strict;
 use warnings;
 
 package Pod::Weaver::PluginBundle::SCHWIGON;
+# git description: v0.002-3-g3228faa
+
 BEGIN {
   $Pod::Weaver::PluginBundle::SCHWIGON::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $Pod::Weaver::PluginBundle::SCHWIGON::VERSION = '0.002';
-}
 # ABSTRACT: Document your modules like SCHWIGON does
-
+$Pod::Weaver::PluginBundle::SCHWIGON::VERSION = '0.003';
 # (well actually like FLORA - as it is shamelessly stolen)
 
 use Pod::Weaver::Config::Assembler;
@@ -41,17 +40,18 @@ sub mvp_bundle_config {
         [ '@SCHWIGON/Authors',   _exp('Authors'),      {} ],
         [ '@SCHWIGON/Legal',     _exp('Legal'),        {} ],
 
-        [ '@SCHWIGON/List',      _exp('-Transformer'), { transformer => 'List' } ],
-        [ '@SCHWIGON/Encoding',  _exp('-Encoding'),    {} ],
+        [ '@SCHWIGON/List',           _exp('-Transformer'),    { transformer => 'List' } ],
+        [ '@SCHWIGON/SingleEncoding', _exp('-SingleEncoding'), {} ],
     );
 }
 
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -106,7 +106,7 @@ This plugin bundle is equivalent to the following weaver.ini file:
   [-Transformer]
   transformer = List
 
-  [-Encoding]
+  [-SingleEncoding]
 
 =for Pod::Coverage mvp_bundle_config
 
@@ -116,10 +116,9 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
